@@ -48,8 +48,30 @@ blocks2vf = function(Block1,Block2,Block3) {
 
     # Use misc3d function to perform the conversion.
     ta    = makeTriangles(Block1,Block2,Block3)
-    ve    = misc3d:::t2ve(ta)
+    ve    = ptinpoly_t2ve(ta)
     verts = t(ve$vb)
     faces = t(ve$ib)
     return (list(verts,faces))
 }
+
+# The following is from an unexported function T2VE in the misc3d package.
+# To avoid name collisions, the name of the function has been modified here.
+ptinpoly_t2ve <- function(triangles) 
+{
+    vb <- rbind(triangles$v1, triangles$v2, triangles$v3)
+    vbmin <- min(vb)
+    vbmax <- max(vb)
+    S <- 10^5
+    score <- function(v, d) floor(as.vector(v %*% d))
+    scale <- function(v) (1 - 1/S) * (v - vbmin)/(vbmax - vbmin)
+    d <- c(S, S^2, S^3)
+    scores <- score(scale(vb), d)
+    vb <- vb[!duplicated(scores), ]
+    scores <- score(scale(vb), d)
+    ib <- rbind(match(score(scale(triangles$v1), d), scores), 
+        match(score(scale(triangles$v2), d), scores), match(score(scale(triangles$v3), 
+            d), scores))
+    list(vb = t(vb), ib = ib)
+}
+
+
